Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrDeadline is returned when the deadline of a request has been exceeded ErrDeadline = errors.New("deadline exceeded") // TableNotFound is returned when attempting to access a table that // doesn't exist on this cluster. TableNotFound = errors.New("table not found") )
Constants
Functions ¶
This section is empty.
Types ¶
type AdminClient ¶
type AdminClient interface {
CreateTable(t *hrpc.CreateTable) error
DeleteTable(t *hrpc.DeleteTable) error
EnableTable(t *hrpc.EnableTable) error
DisableTable(t *hrpc.DisableTable) error
}
AdminClient to perform administrative operations with HMaster
func NewAdminClient ¶
func NewAdminClient(zkquorum string, options ...Option) AdminClient
NewAdminClient creates an admin HBase client.
type Client ¶
type Client interface {
Scan(s *hrpc.Scan) ([]*hrpc.Result, error)
Get(g *hrpc.Get) (*hrpc.Result, error)
Put(p *hrpc.Mutate) (*hrpc.Result, error)
Delete(d *hrpc.Mutate) (*hrpc.Result, error)
Append(a *hrpc.Mutate) (*hrpc.Result, error)
Increment(i *hrpc.Mutate) (int64, error)
CheckAndPut(p *hrpc.Mutate, family string, qualifier string,
expectedValue []byte) (bool, error)
Close()
}
Client a regular HBase client
type Option ¶
type Option func(*client)
func FlushInterval ¶
FlushInterval will return an option that will set the timeout for flushing the RPC queues used in a given client
func RpcQueueSize ¶
RpcQueueSize will return an option that will set the size of the RPC queues used in a given client
func SetZnodeParentOption ¶
Click to show internal directories.
Click to hide internal directories.